Index: extensions/renderer/resources/guest_view/surface_view.js |
diff --git a/extensions/renderer/resources/guest_view/worker_frame.js b/extensions/renderer/resources/guest_view/surface_view.js |
similarity index 60% |
rename from extensions/renderer/resources/guest_view/worker_frame.js |
rename to extensions/renderer/resources/guest_view/surface_view.js |
index 900e43da3d445b05b475df492d34780dbda9bfb8..421aeaae94170febacc8afb5b4b80b4083132163 100644 |
--- a/extensions/renderer/resources/guest_view/worker_frame.js |
+++ b/extensions/renderer/resources/guest_view/surface_view.js |
@@ -2,30 +2,30 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
// This module implements the WorkerFrame prototype. |
var GuestView = require('guestView').GuestView; |
var GuestViewContainer = require('guestViewContainer').GuestViewContainer; |
-function WorkerFrameImpl(workerFrameElement) { |
- GuestViewContainer.call(this, workerFrameElement, 'workerframe'); |
+function SurfaceViewImpl(surfaceviewElement) { |
+ GuestViewContainer.call(this, surfaceviewElement, 'surfaceview'); |
} |
-WorkerFrameImpl.prototype.__proto__ = GuestViewContainer.prototype; |
+SurfaceViewImpl.prototype.__proto__ = GuestViewContainer.prototype; |
-WorkerFrameImpl.VIEW_TYPE = 'WorkerFrame'; |
+SurfaceViewImpl.VIEW_TYPE = 'SurfaceView'; |
// Add extra functionality to |this.element|. |
-WorkerFrameImpl.setupElement = function(proto) { |
+SurfaceViewImpl.setupElement = function(proto) { |
var apiMethods = [ |
'connect' |
]; |
// Forward proto.foo* method calls to WorkerFrameImpl.foo*. |
GuestViewContainer.forwardApiMethods(proto, apiMethods); |
} |
-WorkerFrameImpl.prototype.connect = function(url, callback) { |
+SurfaceViewImpl.prototype.connect = function(url, callback) { |
if (!this.elementAttached) { |
if (callback) { |
callback(false); |
@@ -47,4 +47,4 @@ WorkerFrameImpl.prototype.connect = function(url, callback) { |
}.bind(this)); |
}; |
-GuestViewContainer.registerElement(WorkerFrameImpl); |
+GuestViewContainer.registerElement(SurfaceViewImpl); |
@@ -2,30 +2,30 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-// This module implements the WorkerFrame prototype. |
+// This module implements the SurfaceView prototype. |
var GuestView = require('guestView').GuestView; |
var GuestViewContainer = require('guestViewContainer').GuestViewContainer; |
@@ -2,30 +2,30 @@ |
'connect' |
]; |
- // Forward proto.foo* method calls to WorkerFrameImpl.foo*. |
+ // Forward proto.foo* method calls to SurfaceViewImpl.foo*. |
GuestViewContainer.forwardApiMethods(proto, apiMethods); |
} |